#
# spec file for package mutter
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%if 0%{?suse_version} == 1315
%bcond_with wayland
%else
%bcond_without wayland
%endif

Name:           mutter
Version:        3.20.3
Release:        5.2
Summary:        Window and compositing manager based on Clutter
License:        GPL-2.0+
Group:          System/GUI/GNOME
Url:            http://www.gnome.org
Source:         http://download.gnome.org/sources/mutter/3.20/%{name}-%{version}.tar.xz
# PATCH-FEATURE-SLE mutter-bell.patch FATE#316042 bnc#889218 idonmez@suse.com -- make audible bell work out of the box.
Patch1:         mutter-bell.patch
# PATCH-FIX-SLE relax-some-constraints-on-CSD-windows-in-sle-classic.patch bnc#883491 cxiong@suse.com -- Relax some constraints on window positioning for CSD windows s.t. they can be placed at the very top of the monitor.
Patch2:         relax-some-constraints-on-CSD-windows-in-sle-classic.patch
# PATCH-FIX-UPSTREAM mutter-bsc984738-grab-display.patch bsc#984738 bgo#769387 hpj@suse.com -- Revert a upstream commit to avoid X11 race condition that results in wrong dialog sizes.
Patch3:         mutter-bsc984738-grab-display.patch
BuildRequires:  fdupes
BuildRequires:  gobject-introspection-devel >= 0.9.5
BuildRequires:  intltool
BuildRequires:  libSM-devel
BuildRequires:  libX11-devel
BuildRequires:  libXinerama-devel
%if !0%{?is_opensuse}
BuildRequires:  translation-update-upstream
%endif
BuildRequires:  update-desktop-files
BuildRequires:  zenity
BuildRequires:  pkgconfig(cairo) >= 1.10.0
BuildRequires:  pkgconfig(clutter-1.0) >= 1.25.6
BuildRequires:  pkgconfig(cogl-1.0) >= 1.17.1
BuildRequires:  pkgconfig(gio-unix-2.0) >= 2.25.10
BuildRequires:  pkgconfig(gnome-desktop-3.0)
BuildRequires:  pkgconfig(gsettings-desktop-schemas) >= 3.19.3
BuildRequires:  pkgconfig(gtk+-3.0) >= 3.19.7
BuildRequires:  pkgconfig(libcanberra-gtk3)
BuildRequires:  pkgconfig(libstartup-notification-1.0)
BuildRequires:  pkgconfig(pango) >= 1.2.0
BuildRequires:  pkgconfig(upower-glib) >= 0.99.0
BuildRequires:  pkgconfig(x11-xcb)
BuildRequires:  pkgconfig(xcb-randr)
BuildRequires:  pkgconfig(xcomposite) >= 0.2
BuildRequires:  pkgconfig(xcursor)
BuildRequires:  pkgconfig(xdamage)
BuildRequires:  pkgconfig(xext)
BuildRequires:  pkgconfig(xfixes)
BuildRequires:  pkgconfig(xi)
BuildRequires:  pkgconfig(xkbcommon) >= 0.4.3
BuildRequires:  pkgconfig(xkbcommon-x11)
BuildRequires:  pkgconfig(xkbfile)
BuildRequires:  pkgconfig(xkeyboard-config)
BuildRequires:  pkgconfig(xrandr) >= 1.5.0
BuildRequires:  pkgconfig(xrender)
%if %{with wayland}
BuildRequires:  pkgconfig(clutter-egl-1.0)
BuildRequires:  pkgconfig(clutter-wayland-1.0)
BuildRequires:  pkgconfig(clutter-wayland-compositor-1.0)
BuildRequires:  pkgconfig(gbm) >= 10.3
BuildRequires:  pkgconfig(gudev-1.0)
BuildRequires:  pkgconfig(libdrm)
BuildRequires:  pkgconfig(libinput)
BuildRequires:  pkgconfig(libsystemd)
BuildRequires:  pkgconfig(wayland-protocols) >= 1.0
BuildRequires:  pkgconfig(wayland-server) >= 1.4.93
%endif
Requires:       zenity
Recommends:     %{name}-lang
Provides:       windowmanager
# mutter 3.9.90 dropped old, unused tools. Likely, nobody has them installed anyway
Obsoletes:      %{name}-tools < %{version}
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Mutter is a window and compositing manager based on Clutter, forked
from Metacity.

%package -n libmutter0
Summary:        Window and compositing manager based on Clutter -- Library
Group:          System/Libraries
# we need the gsettings schema; hopefully, they'll stay backwards compatible
# (since we can't require = version, to not break SLPP)
Requires:       %{name}-data >= %{version}

%description -n libmutter0
Mutter is a window and compositing manager based on Clutter, forked
from Metacity.

This package contains a library for shared features.

%package -n typelib-1_0-Meta-3_0
Summary:        Window and compositing manager based on Clutter -- Introspection bindings
Group:          System/Libraries

%description -n typelib-1_0-Meta-3_0
Mutter is a window and compositing manager based on Clutter, forked
from Metacity.

This package provides the GObject Introspection bindings for libmutter.

%package data
Summary:        Window and compositing manager based on Clutter -- Data Files
Group:          System/GUI/GNOME
Requires:       %{name} = %{version}
%glib2_gsettings_schema_requires

%description data
Mutter is a window and compositing manager based on Clutter, forked
from Metacity.

This package contains data files needed by mutter and its library.

%package devel
Summary:        Include Files and Libraries mandatory for Development
Group:          Development/Libraries/GNOME
Requires:       libmutter0 = %{version}
Requires:       typelib-1_0-Meta-3_0 = %{version}

%description devel
This package contains all necessary include files and libraries needed
to develop applications that require these.


%lang_package
%prep
%setup -q
%if !0%{?is_opensuse}
translation-update-upstream
%patch1 -p1
%patch2 -p1
%endif
%patch3 -p1

%build
%configure \
%if %{with wayland}
        --enable-wayland \
        --enable-native-backend \
%else
        --disable-wayland \
        --disable-native-backend \
%endif
        --disable-static \
        --enable-compile-warnings=maximum
make %{?_smp_mflags} V=1

%install
%make_install
find %{buildroot}%{_libdir} -type f -name '*.la' -delete -print
%suse_update_desktop_file %{name}
%find_lang %{name} %{?no_lang_C}
%fdupes %{buildroot}

%clean
rm -rf %{buildroot}

%post
%desktop_database_post

%postun
%desktop_database_postun

%post -n libmutter0 -p /sbin/ldconfig

%postun -n libmutter0 -p /sbin/ldconfig

%post data
%glib2_gsettings_schema_post

%postun data
%glib2_gsettings_schema_postun

%files
%defattr (-, root, root)
%doc COPYING NEWS
%{_bindir}/mutter
%{_libdir}/mutter/plugins/default.so
%{_libexecdir}/mutter-restart-helper
%{_datadir}/applications/mutter.desktop
%doc %{_mandir}/man1/mutter.1%{?ext_man}

%files -n libmutter0
%defattr(-,root,root)
%{_libdir}/libmutter.so.*
%dir %{_libdir}/mutter/
# users of libmutter need this directory
%dir %{_libdir}/mutter/plugins/

%files -n typelib-1_0-Meta-3_0
%defattr(-,root,root)
%{_libdir}/mutter/Meta-3.0.typelib

%files data
%defattr(-,root,root)
# Do not depend on g-c-c just for a directory
%dir %{_datadir}/gnome-control-center
%dir %{_datadir}/gnome-control-center/keybindings
%{_datadir}/gnome-control-center/keybindings/50-mutter-windows.xml
%{_datadir}/gnome-control-center/keybindings/50-mutter-navigation.xml
%{_datadir}/gnome-control-center/keybindings/50-mutter-system.xml
%{_datadir}/GConf/gsettings/mutter-schemas.convert
%{_datadir}/glib-2.0/schemas/org.gnome.mutter.gschema.xml
%{_datadir}/glib-2.0/schemas/org.gnome.mutter.wayland.gschema.xml

%files lang -f %{name}.lang

%files devel
%defattr(-,root,root)
%{_includedir}/mutter/
%{_libdir}/libmutter.so
%{_libdir}/mutter/Meta-3.0.gir
%{_libdir}/pkgconfig/libmutter.pc

%changelog
* Sat Jul 30 2016 hpj@suse.com
- Add mutter-bsc984738-grab-display.patch (bsc#984738, bgo#769387).
* Wed Jun 29 2016 zaitor@opensuse.org
- Update to version 3.20.3:
  + Fix grabbing random keys for disabled shortcuts (bgo#766270).
  + Crash fixes (bgo#751847, bgo#767969).
  + Improve multi-monitor handling on wayland (bgo#766528).
  + Don't create invalid UTF-8 window description strings
    (bgo#765535).
  + Convert window titles and wm_class to UTF-8 (bgo#752788).
  + Use kill() to force-quit unresponsive wayland clients
    (bgo#767464).
  + Fix window position when unmaximizing via DND on wayland
    (bgo#764180).
  + Avoid full window redraws when using extended frame sync
    (bgo#767798).
  + Fix missing frame border around GTK+ dialogs (bgo#745060).
  + Improve X11 <-> wayland copy and paste interaction
    (bgo#768007).
  + Updated translations.
* Wed May 11 2016 zaitor@opensuse.org
- Update to version 3.20.2:
  + Notify clients of pending modifier state changes (bgo#748526).
  + Add get_is_builtin_display_on() method (bgo#765267).
  + Fix 2-finger titlebar taps on wayland (bgo#764519).
  + Misc. bug fixes: bgo#765058, bgo#765252, bgo#765062.
  + Updated translations.
- Conditionally apply translations-update-upstream BuildRequires
  and macro for non-openSUSE only.
* Mon May  2 2016 fcrozat@suse.com
- Drop mutter-grab-display.patch, it has been fixed by upstream
  differently.
* Wed Apr 13 2016 zaitor@opensuse.org
- Update to version 3.20.1:
  + Constrain window move/resizes on wayland as on X11
    (bgo#748819).
  + Don't crash with invalid previous monitor configurations
    (bgo#764286).
  + Misc. bug fixes and cleanups: bgo#762828, bgo#764807.
  + Updated translations.
* Wed Apr 13 2016 idonmez@suse.com
- Update to GNOME 3.20  Fate#318572
- Remove upstream patches: mutter-bnc879109-no-monitors-crash.patch
- Refresh mutter-grab-display.patch, mutter-bell.patch,
  relax-some-constraints-on-CSD-windows-in-sle-classic.patch
* Wed Mar 23 2016 dimstar@opensuse.org
- Update to version 3.20.0:
  + Fix crash when using visual bell (bgo#763858).
  + Updated translations.
* Thu Mar 17 2016 dimstar@opensuse.org
- Update to version 3.19.92:
  + Add system bell support on wayland (bgo#763284).
  + Add gtk_surface.present to gtk-shell (bgo#763295).
  + Handle DND drops on the root window (bgo#762104).
  + Misc. bug fixes: bgo#762828, bgo#760745, bgo#763125,
    bgo#762763, bgo#762661, bgo#762639, bgo#763159.
  + Updated translations.
* Fri Mar  4 2016 fcrozat@suse.com
- BuildRequires pkgconfig(libdrm), pkgconfig(libinput),
  pkgconfig(libsystemd) are only needed when building native
  backend, which is useful only under wayland and when running as
  display server. Ensure they aren't pulled as BuildRequires when
  wayland support is disabled. Add --enable-native-backend when
  building wayland support.
* Thu Mar  3 2016 zaitor@opensuse.org
- Update to version 3.19.91:
  + Add --nested CLI argument to fix nested wayland session
    (bgo#758658).
  + Fix stack - scene graph stacking synchronization issues
    (bgo#755605).
  + Rate-limit last-device changes to fix freezes (bgo#753527).
  + Implement primary selection protocol (bgo#762560).
  + Misc. bug fixes: bgo#762878, bgo#762716.
  + Updated translations.
* Fri Feb 19 2016 zaitor@opensuse.org
- Update to version 3.19.90:
  + Release buffer after processing commit (bgo#761312,
    bgo#761613).
  + Implement pointer motion, locks and confinement on wayland
    (bgo#744104).
  + Add basic startup notification support on wayland (bgo#762268).
  + Misc. bug fixes: bgo#760670, bgo#761543, bgo#752794,
    bgo#761557.
* Fri Jan 22 2016 dimstar@opensuse.org
- Update to version 3.19.4:
  + Fix updating stacking order when setting transient_for
    (bgo#755606).
  + Support screen rotation when supported by the driver
    (bgo#745079).
  + Protect against broken WM_CLASS property implementations
    (bgo#759658).
  + Handle wl_pointer v5 events on wayland (bgo#760637).
  + Implement DND actions on wayland (bgo#760805).
  + Misc. bug fixes: bgo#754711, bgo#756789, bgo#759297,
    bgo#758613, bgo#760330, bgo#760476, bgo#759222, bgo#760670.
  + Updated translations.
* Thu Dec 17 2015 dimstar@opensuse.org
- Update to version 3.19.3:
  + Correct refresh rate units on KMS/Wayland (bgo#758653).
  + Fix crash when initial cursor position is not on a monitor
    (bgo#756698).
  + Fix crash when more CRTs are enabled than outputs connected
    (bgo#751638).
  + Fix touch pointer emulation on wayland (bgo#756754).
  + Allow minimizing windows that don't advertise supporting it
    (bgo#758186).
  + Force 2-finger scroll by default if available (bgo#759304).
  + Fix crash during XWayland initialization (bgo#751845).
  + Ensure to send a ConfigureNotify to just mapped windows
    (bgo#759492).
  + Misc. bug fixes and cleanups: bgo#758239, bgo#758633,
    bgo#755503, bgo#759374.
  + Updated translations.
- Add pkgconfig(wayland-protocols) BuildRequires: new dependency.
* Wed Nov 25 2015 zaitor@opensuse.org
- Update to version 3.19.2:
  + Fix crash on monitor unplug (bgo#756796).
  + Exit cleanly on initialization errors (bgo#757311).
  + Allow to determine backend setting from session type
    (bgo#741666).
  + Fix DRM device detection for non-PCI devices (bgo#754911).
  + Don't force placement of windows without buffer on wayland
    (bgo#751887).
  + Fix initialization of bypass compositor hint (bgo#758544).
* Wed Nov 25 2015 zaitor@opensuse.org
- Update to version 3.19.1:
  + wayland: Allow to trigger popups through keyboard/touch
    (bgo#756296).
  + Fix modifiers-only input source switching on Ubuntu
    (bgo#756543).
  + Misc. bug fixes: bgo#756675, bgo#756660, bgo#746420,
    bgo#756548, bgo#756796, bgo#757101, bgo#757148.
  + Updated translations.
* Thu Nov 12 2015 zaitor@opensuse.org
- Update to version 3.18.2:
  + Misc. crash fixes (bgo#756675, bgo#756660, bgo#757148,
    bgo#756796).
  + Fix modifiers-only input source switching on Ubuntu.
  + Exit cleanly on initialization errors (bgo#757311).
  + Updated translations.
* Thu Oct 15 2015 zaitor@opensuse.org
- Update to version 3.18.1:
  + Improve HiDPI support on wayland (bgo#755097).
  + Fix doubly-scaled cursor on XWayland HiDPI (bgo#755099).
  + Stop hiding titlebar buttons in dialogs (bgo#641630).
  + Add support for fullscreen/unfullscreen animations
    (bgo#707248).
  + Misc. crash fixes: bgo#755096, bgo#754979, bgo#755490,
    bgo#754357, bgo#745785, bgo#756642.
  + Misc. bug fixes: bgo#743339, bgo#752047, bgo#756074,
    bgo#756649.
- Drop wayland-Dont-pre-multiply-root-cursor-sizes.patch and
  wayland-Dont-scale-XWayland-pointer-cursor-sprites.patch: Fixed
  upstream.
* Fri Oct  2 2015 zaitor@opensuse.org
- Add wayland-Dont-pre-multiply-root-cursor-sizes.patch and
  wayland-Dont-scale-XWayland-pointer-cursor-sprites.patch: taken
  from upstream git. Fixes for HiDPI under wayland (bgo#755099).
* Tue Sep 22 2015 dimstar@opensuse.org
- Update to version 3.18.0:
  + Misc. fixes: bgo#753434.
  + Updated translations.
- Drop Revert-launcher-simplify-getting-session-dbus-proxy.patch:
  fixed upstream.
* Sat Sep 19 2015 zaitor@opensuse.org
- Add Revert-launcher-simplify-getting-session-dbus-proxy.patch:
  fix VT switching with wayland, patch from upstream git.
* Wed Sep 16 2015 dimstar@opensuse.org
- Update to version 3.17.92:
  + Don't omit the background color for backgrounds that don't fill
    the screen (bgo#754476).
  + Fix up key state on FocusIn when running nested (bgo#753948).
  + Find the right DRM device instead of hardcoding card0
    (bgo#753434).
  + Scale cursor on HiDPI screens (bgo#744932).
  + Misc. fixes and cleanups (bgo#754545, bgo#754215, bgo#754621,
    bgo#754715).
  + Updated translations.
* Thu Sep  3 2015 zaitor@opensuse.org
- Update to version 3.17.91:
  + Send error on pointer-gesture protocol version mismatch
    (bgo#753855).
  + Misc. cleanups (bgo#744932).
  + Updated translations.
* Thu Aug 20 2015 zaitor@opensuse.org
- Update to version 3.17.90:
  + Fix glitch with some fullscreen apps (bgo#753020).
  + Fix screen update issue with NVidia driver (bgo#728464).
  + Only call frame callbacks for surfaces that get drawn
    (bgo#739163).
  + Misc. bug fixes and cleanups: bgo#753222, bgo#752753,
    bgo#753237, bgo#753380, bgo#744104, bgo#744932.
  + Updated translations.
- Drop upstream fixed patches:
  + build_fix_return_value_in_meta-sync-ring.c.patch
  + compositor_add_support_for_GL_EXT_x11_sync_object.patch
  + compositor_fix_GL_EXT_x11_sync_object_race_condition.patch
  + compositor_handle_fences_in_the_frontend_X_connection.patch
* Thu Aug 13 2015 idonmez@suse.com
- Fix screen flickering on nvidia devices (bgo#728464).
  + Add the following commits from the 3.16 branch:
  - build_fix_return_value_in_meta-sync-ring.c.patch
  - compositor_add_support_for_GL_EXT_x11_sync_object.patch
  - compositor_fix_GL_EXT_x11_sync_object_race_condition.patch
  - compositor_handle_fences_in_the_frontend_X_connection.patch
- Added autoconf and automake BuildRequires and run autoreconf for
  the patches above.
* Thu Jul 23 2015 zaitor@opensuse.org
- Update to version 3.17.4:
  + nested: Allow basic configuration of dummy outputs
    (bgo#747089).
  + Send wl_surface.enter and wl_surface.leave on output changes
    (bgo#744453).
  + Improve HiDPI handling on wayland (bgo#745655, bgo#744934).
  + Implement compositor-side animated cursors (bgo#752342).
  + Bugs fixed: bgo#750816, bgo#751884, bgo#752248, bgo#752551,
    bgo#752552, bgo#752673, bgo#752674.
- Drop mutter-devel-doc sub-package, removed upstream.
* Mon Jul  6 2015 zaitor@opensuse.org
- Update to version 3.17.3:
  + Add X11/wayland clipboard interaction (bgo#738312).
  + Support VM monitor layout hints on wayland (bgo#750363).
  + Bugs fixed: bgo#749994, bgo#750256, bgo#749716, bgo#748705,
    bgo#750552, bgo#751036, bgo#750007, bgo#751136, bgo#750552,
    bgo#751471, bgo#751715, bgo#750680.
  + Updated translations.
  + Add pkgconfig(xrandr) BuildRequires: New optional dependency.
* Thu Jul  2 2015 zaitor@opensuse.org
- Update to version 3.17.2:
  + Honor default value for click method setting (bgo#746290).
  + Add X11/wayland clipboard interoperation (bgo#738312).
  + Misc. bug fixes: bgo#749076, bgo#749711.
* Thu Jul  2 2015 zaitor@opensuse.org
- Update to version 3.17.1:
  + Add public method to get neighboring monitor (bgo#633994).
  + Apply the right settings to the right input devices
    (bgo#747886).
  + Fix scroll button setting (bgo#747967).
  + Add support for modal hint on wayland (bgo#745720).
  + Don't reset idle time for non-hardware events (bgo#748541).
  + Misc. bug fixes (bgo#748478).
* Thu Jul  2 2015 zaitor@opensuse.org
- Update to version 3.16.3:
  + Fix kill dialog not showing when first PING fails (bgo#749076).
  + wayland: Reset idle time appropriately (bgo#749711,
    bgo#749994).
  + Fix crash when trying to focus a hidden window (bgo#751715).
  + Updated translations.
* Thu May 14 2015 zaitor@opensuse.org
- Update to version 3.16.2:
  + Fix scroll button setting (bgo#747967).
  + Don't reset idle time for non-hardware events (bgo#748541).
  + Honor default value for click method setting (bgo#746290).
  + Misc. bug fixes (bgo#748478).
* Wed Apr 15 2015 zaitor@opensuse.org
- Update to version 3.16.1.1:
  + Prevent a crash when switching VTs or adding input devices
    (bgo#747886).
* Wed Apr 15 2015 dimstar@opensuse.org
- Update to version 3.16.1:
  + Add function to refresh all background instances (bgo#739178).
  + Fix swapped scroll methods on wayland (bgo#746870).
  + Manually activate stage to fix accessibility on wayland
    (bgo#746670).
  + Center pointer on primary monitor on startup (bgo#746896).
  + wayland: Reword synchronized state application semantics
    (bgo#743617).
  + Ensure input settings are applied on startup (bgo#747434).
  + Misc. bug fixes: bgo#744932, bgo#746509, bgo#746692,
    bgo#746510, bo#746545, bgo#747263.
  + Updated translations.
- Add pkgconfig(xrender) BuildRequires: new verified dependency.
- Drop mutter-nvidia-repaint-on-resume.patch: fixed upstream.
* Thu Mar 26 2015 dimstar@opensuse.org
- Change from simple %%defines to %%bcond_with/without, as this
  allows to be set in prjconf without the need to patch the .spec
  files.
  + build_wayland has been replaced with the equivalent
    %%bcond_with, resp. %%bcond_without, based on the value that was
    originally set, resulting in no change for the build.
* Mon Mar 23 2015 dimstar@opensuse.org
- Update to version 3.16.0:
  + wayland: Don't skip notifying about initial maximized state
    (bgo#745303).
  + Updated translations.
- Add mutter-nvidia-repaint-on-resume.patch: Add a function to
  refresh all background instances (boo#914149, bgo#739178).
* Wed Mar 18 2015 dimstar@opensuse.org
- Update to version 3.15.92:
  + Ensure pointer visibility on monitor changes (bgo#745121,
    bgo#745752).
  + Fix geometry of shaded windows (bgo#746145).
  + Take over cursor visibility handling from gsd (bgo#712775).
  + Fix touch interaction on window decorations (bgo#745335).
  + Add options for libinput_config_click_method (bgo#746290).
  + Scale window decorations on HiDPI displays (bgo#744354).
  + Misc. bug fixes: bgo#745163, bgo#746295, bgo#746098,
    bgo#745734.
  + Updated translations.
* Thu Mar  5 2015 dimstar@opensuse.org
- Update to version 3.15.91:
  + wayland: Fix nested compositor mode (bgo#745401).
  + wayland: Fix pointer constraining (bgo#727337).
  + wayland: Fix input region on HiDPI (bgo#744933).
  + Allow themes to style buttons differently based on function
    (bgo#745108).
  + Misc. bug fixes and cleanups: bgo#745141, bgo#745118,
    bgo#745476, bgo#745442.
  + Updated translations.
* Fri Feb 20 2015 dimstar@opensuse.org
- Update to version 3.15.90:
  + Initialize MetaOutput even when we can't get the EDID
    (bgo#743412).
  + Expose MetaMonitorManager to introspection (bgo#743745).
  + Fix flash on unredirection (bgo#743858).
  + Update xdg-shell implementation to v5 (bgo#744452).
  + Do not try to use seat devices that aren't (yet) present
    (bgo#744640).
  + Add keybindings for switching to VT8-VT12 (bgo#744800).
  + Misc bug fixes: bgo#743678, bgo#744500.
* Fri Feb 20 2015 dimstar@opensuse.org
- Add pkgconfig(gudev-1.0) and pkgconfig(gbm) BuildRequires in case
  we're building with wayland support: Needed for the native (non
  nested support).
* Fri Jan 23 2015 zaitor@opensuse.org
- Update to version 3.15.4:
  + Use GTK+ theme for window decorations instead of metacity
    (bgo#741917).
  + Export the same EDID information on X11 and wayland
    (bgo#742882).
  + Apply input device configuration on wayland (bgo#739397).
  + Implement pointer barriers on wayland (bgo#706655).
  + Bugs fixed: bgo#741829, bgo#738630, bgo#737463, bgo#698995,
    bgo#727893, bgo#742825, bgo#742824, bgo#742841, bgo#743173,
    bgo#743189, bgo#743217, bgo#743254.
  + Updated translations.
* Fri Dec 19 2014 zaitor@opensuse.org
- Update to version 3.15.3:
  + Don't leave left-over frames queued (bgo#738686).
  + Set CRTC configuration even if it might be redundant
    (bgo#740838).
  + Updated translations.
* Fri Dec 19 2014 zaitor@opensuse.org
- Update to version 3.15.2:
  + Don't enable hiDPI on monitors with broken EDID (bgo##734839).
  + Prevent crash applying monitor config for a closed lid
    (bgo#739450).
  + Fix "flicker" during startup transition (bgo#740377).
  + Bugs fixed: bgo#731521, bgo#740133, bgo#738890.
* Fri Dec 19 2014 zaitor@opensuse.org
- Update to version 3.15.1:
  + Use GResources for theme loading (bgo#736936).
  + Fix headerbar drag getting stuck on xwayland (bgo#738411).
- Drop following patches: mutter-black-screen-during-login.patch,
  mutter-window-actor-unredirection-when-destroyed.patch,
  mutter-empty-input-shapes-windows.patch,
  mutter-left-over-queued-frames.patch,
  mutter-dont-overwrite-send_frame_messages_timer.patch, all fixed
  upstream.
* Fri Dec 19 2014 zaitor@opensuse.org
- Update to version 3.14.3:
  + Fix crash when trying to unredirect a destroyed window
    (bgo#740133).
  + Fix "flicker" during startup transition (bgo#740377).
  + Don't leave left-over frames queued (bgo#738686).
  + Set CRTC configuration even if it might be redundant
    (bgo#740838).
- Drop upstreamed patches:
  + mutter-black-screen-during-login.patch.
  + mutter-window-actor-unredirection-when-destroyed.patch.
  + mutter-empty-input-shapes-windows.patch.
  + mutter-left-over-queued-frames.patch.
  + mutter-dont-overwrite-send_frame_messages_timer.patch.
* Fri Dec 12 2014 fcrozat@suse.com
- Disable wayland on SLE12.
- Remove BuildRequires pkgconfig(gbm), not needed unless building
  native backend.
* Thu Dec  4 2014 badshah400@gmail.com
- Add post-release fixes from upstream:
  + mutter-black-screen-during-login.patch: Disable ugly black
    screen during login (bgo#740377).
  + mutter-window-actor-unredirection-when-destroyed.patch:
    window-actor: Do not request unredirection when destroyed
    (bgo#740133).
  + mutter-empty-input-shapes-windows.patch: window-x11: Fix
    windows that set empty input shapes.
  + mutter-left-over-queued-frames.patch: Fix problems resulting
    in left-over queued frames (bgo#738686).
  + mutter-dont-overwrite-send_frame_messages_timer.patch:
    MetaWindowActor: don't overwrite send_frame_messages_timer
    (bgo#738686).
* Wed Nov 12 2014 zaitor@opensuse.org
- Update to version 3.14.2:
  + Prevent crash applying monitor config for a closed lid
    (bgo#739450).
  + Misc. fixes.
* Wed Nov 12 2014 zaitor@opensuse.org
- Update to version 3.14.1.5:
  + Fix wayland hiDPI regression (bgo#739161).
  + Updated translations.
* Wed Oct 15 2014 dimstar@opensuse.org
- Update to version 3.14.1:
  + Fix move-titlebar-onscreen function (bgo#736915).
  + Fix stacking of the guard window (bgo#737233).
  + Fix keycode lookup for non-default layouts (bgo#737134).
  + Fix workspaces-only-on-primary handling (bgo#737178).
  + Don't unstick sticky windows on workspace removal (bgo#737625).
  + Do not auto-minimize fullscreen windows (bgo#705177).
  + Upload keymap to newly added keyboard devices (bgo#737673).
  + Apply keyboard repeat settings (bgo#728055).
  + Don't send pressed keys on enter (bgo#727178).
  + Fix build without wayland/native (bgo#738225).
  + Send modifiers after the key event (bgo#738238).
  + Fix unredirect heuristic (bgo#738271).
  + Do not show system chrome over fullscreen windows (bgo#693991).
  + Misc. bug fixes: bgo#737135, bgo#737581, bgo#738146,
    bgo#738384.
  + Updated translations.
* Tue Sep 23 2014 dimstar@opensuse.org
- Update to version 3.14.0:
  + Fix placement of popup windows on wayland (bgo#736812).
  + Only increment serial once per event (bgo#736840).
  + Fix window positioning regression with non-GTK+ toolkits
    (bgo#736719).
  + Updated translations.
* Wed Sep 17 2014 dimstar@opensuse.org
- Update to version 3.13.92:
  + Rewrite background code (bgo#735637, bgo#736568).
  + Fix size in nested mode (bgo#736279).
  + Fix destroy animation of background windows (bgo#735927).
  + Wire keymap changes up to the wayland frontend (bgo#736433).
  + Add a test framework and stacking tests [Owen; #736505]
  + Simplify handling of the merged X and wayland stack
    (bgo#736559).
  + Fix cursor size on HiDPI (bgo#729337).
  + Misc. bug fixes: bgo#735632, bgo#736589, bgo#736694.
* Mon Sep  8 2014 dimstar@opensuse.org
- Update to version 3.13.91:
  + Misc. bug fixes: bg0#735452.
  + Updated translations.
- Add pkgconfig(gbm) and pkgconfig(x11-xcb) BuildRequires: new
  explicit dependencies.
* Wed Aug 20 2014 dimstar@opensuse.org
- Update to version 3.13.90:
  + Only call XSync() once per frame (bgo#728464).
  + Update capabilities on device list changes (bgo#733563).
  + Make use of GLSL optional (bgo#733623).
  + Handle gestures and touch events on wayland (bgo#733631).
  + Add support for unminimize compositor effects (bgo#733789).
  + Always set the frame background to None (bgo#734054).
  + Add backend methods to handle keymaps (bgo#734301).
  + Actually mark revalidated MetaTextureTower levels as valid
    (bgo#734400).
  + Rely on explicit -backward switcher keybindings instead of
    <shift>-magic (bgo#732295, bgo#732385).
  + Misc. bug fixes and cleanups: bgo#727178, bgo#734852,
    bgo#734960.
  + Updated translations.
- Add pkgconfig(xkbfile), pkgconfig(xkeyboard-config),
  pkgconfig(xkbcommon), pkgconfig(xkbcommon-x11) and
  pkgconfig(xcb-randr) BuildRequires: new dependencies.
* Thu Aug 14 2014 idonmez@suse.com
- Update mutter-bell.patch so it works on all cases (bnc#889218)
* Wed Jul 23 2014 dimstar@opensuse.org
- Update to version 3.13.4:
  + Fix move/resize operations for wayland clients (bgo#731237).
  + Add ::first-frame signal to MetaWindowActor (bgo#732343).
  + Handle keysyms without the XF86 prefix (bgo#727993).
  + Add touch gesture support.
  + Fix a deadlock when exiting (bgo#733068).
  + Add framework for restarting the compositor with nice visuals
    (bgo#733026).
  + Toggle seat capabilities on VT switch (bgo#733563).
  + Misc bug fixes: bgo#732695, bgo#732350.
  + Updated translations.
- Replace pkgconfig(gio-2.0) BuildRequires with
  pkgconfig(gio-unix-2.0), following upstreams change in configure.
- Add pkgconfig(libinput) BuildRequires: new dependency.
* Sat Jul 12 2014 dimstar@opensuse.org
- Update to version 3.13.3:
  + Improve behavior of window buttons with compositor menus
    (bgo#731058).
  + Implement touch support on wayland (bgo#724442).
  + Update window shadows (bgo#731866).
  + Keep windows on the preferred output (bgo#731760]).
  + Misc bug fixes: bgo#729601, bgo#730681, bgo#731353, bgo#731332,
    bgo#730527, bgo#662962.
- Changes from version 3.13.2:
  + Add basic HiDPI support on wayland (bgo#728902).
  + Replace mutter-launch with logind integration (bgo#724604]).
  + Move window menu into the compositor (bgo#726352).
  + Fix delayed focus-follows-mouse support (bgo#730541).
  + Support fallback app menu in window decorations (bgo#730752).
  + Misc. bug fixes and cleanups: bgo#729732, bgo#729602,
    bgo#726714.
  + Updated translations.
- Changes from version 3.13.1:
  + Merge wayland branch.
  + Don't prevent workspace switches for present_with_time()
    (bgo#728018).
  + Add shortcuts for switching to the last workspace (bgo#659288).
  + Make move/resize menu items behave like the keybindings
    (bgo#728617).
  + Misc. bug fixes and cleanups: bgo#720631, bgo#727979,
    bgo#728423, bgo#728395, bgo#729044.
  + Updated translations.
- Replace pkgconfig(xrender) BuildRequires with pkgconfig(xext),
  following upstream changes.
- Add BuildRequires for the newly merged Wayland support:
  + pkgconfig(clutter-egl-1.0), pkgconfig(clutter-wayland-1.0),
    pkgconfig(clutter-wayland-compositor-1.0) and
    pkgconfig(wayland-server).
- Add BuildRequires for session startup support using systemd:
  + pkgconfig(libdrm) and pkgconfig(libsystemd).
* Wed Jul  9 2014 cxiong@suse.com
- Add relax-some-constraints-on-CSD-windows-in-sle-classic.patch:
  CSD (Client Side Decoration) windows have invisible box wrapping
  around them, which leads to some positioning issues as in this
  bug report. Relax some constraints on window positioning for CSD
  windows s.t. they can be placed at the very top of the monitor.
  This fix works nicely for "sle-classic" as there is no top bar
  any more, and is NOT applied in other GNOME sessions for reasons
  stated in bgo#719772 (bnc#883491).
* Sat May 31 2014 federico@suse.com
- Add mutter-bnc879109-no-monitors-crash.patch:
  Fixes a crash in Mutter when there are no usable monitors, such
  as when a laptop is booted with the lid closed while on a docking
  station, with the intent of plugging an external monitor later
  (bnc#879109).
* Sat May 17 2014 zaitor@opensuse.org
- Update to version 3.12.2:
  + Fix in-fullscreen state when moving between monitors
    (bgo#728395).
  + Fix crash when monitors change during suspend (bgo#725637).
  + Misc. bugs fixed: bgo#728423, bgo#729732.
  + Updated translations.
* Wed May  7 2014 sbrabec@suse.cz
- Added support for gnome-patch-translation (2 strings).
* Mon Apr 28 2014 dliang@suse.com
- Update mutter-grab-display.patch to fix (bnc#873763)
  remove the duplicated trap-pop.
* Wed Apr 16 2014 dimstar@opensuse.org
- Update to version 3.12.1:
  + Fix opacity values from _NET_WM_WINDOW_OPACITY (bgo#727874).
  + Misc. cleanups (bgo#720631).
  + Updated translations.
* Sat Apr  5 2014 dimstar@opensuse.org
- Move %%{_datadir}/gtk-doc/html/meta/ to a separate devel-doc
  package (in order to not conflict between mutter and
  mutter-wayland).
* Fri Mar 28 2014 dliang@suse.com
- Add mutter-grab-display.patch (bnc#870285)
  The oracle installer cannot display correctly.
  The bug was introduced in 3.10.4 and is now fixed in upstream.
* Wed Mar 26 2014 zaitor@opensuse.org
- Update to version 3.12.0:
  + Updated translations.
* Thu Mar 20 2014 dimstar@opensuse.org
- Update to version 3.11.92:
  + Fix identification of CSD windows (bgo#723029).
  + Add minimal handling of touch events (bgo#723552).
  + Misc bug fixes and cleanups: bgo#723580, bgo#726352.
  + Updated translations.
* Thu Mar  6 2014 dimstar@opensuse.org
- Update to version 3.11.91:
  + Don't use keysym to match keybindings (bgo#678001).
  + Fix message tray icons showing up blank (bgo#725180).
  + Improve keybinding lookups (bgo#725588).
  + Fix dynamic updates of titlebar style properties (bgo#725751).
  + Fix positioning of manually positioned windows (bgo#724049).
  + Misc. bug fixes: bgo#724969, bgo#724402, bgo#722266,
    bgo#725338.
  + Updated translations.
* Thu Feb 20 2014 zaitor@opensuse.org
- Update to version 3.11.90:
  + Use correct output property for backlight control (bgo#723606).
  + Fix double-scaling on high DPI resolutions (bgo#723931).
  + Make tile previews a compositor effect (bgo#665758).
  + Bugs fixed: bgo#722530, bgo#724257, bgo#724258, bgo#724364,
    bgo#720631, bgo#707851, bgo#707897.
  + Updated translations.
* Thu Feb 20 2014 dimstar@opensuse.org
- Update to version 3.11.5:
  + Fix CSD titlebars being placed off-screen (bgo#719772).
  + Expose MetaWindow:skip-taskbar property (bgo#723307).
  + Fix legacy tray icons showing up blank (bgo#721596).
  + Fix configuration of cloned monitors (bgo#710610).
  + Misc bug fixes and cleanups (bgo#720631, bgo#723468,
    bgo#723563).
  + Updated translations.
* Thu Feb 20 2014 zaitor@opensuse.org
- Update to version 3.11.4:
  + Don't leave focus on windows that are being unmanaged
    (bgo#711618).
  + Reduce server grabs (bgo#721345, bgo#721709).
  + Improve heuristic to determine display output name
    (bgo#721674).
  + Atomically unmaximize both directions (bgo#722108).
  + Misc bug fixes (bgo#721517, bgo#721674).
* Thu Feb 20 2014 dimstar@opensuse.org
- Update to version 3.11.3:
  + xrandr: Use "hotplug_mode_update" property (bgo#707194).
  + Fix position of attached dialogs for CSD windows (bgo#707194).
  + Fix focus issues with external OSKs (bgo#715030).
  + Add a MetaCullable interface (bgo#714706).
  + Fix window group paint volume (bgo#719669).
  + Fix frame extents problems (bgo#714707).
  + Add shortcut to move windows between monitors (bgo#671054).
  + Fix problems with focus tracking (bgo#720558).
  + Misc. bug fixes and cleanups: bgo#712833, bgo#678989,
    bgo#720106, bgo#720417, bgo#720630.
  + Updated translations.
* Thu Feb 20 2014 dimstar@opensuse.org
- Update to version 3.11.2:
  + Fix resize operations using mouse-button-modifier (bgo#710251).
  + Misc. fixes and cleanups (bgo#711731).
* Thu Feb 20 2014 dimstar@opensuse.org
- Update to version 3.11.1:
  + Name the guard window (bgo#710346).
  + Use new UPower API.
  + Expose min-backlight-stea (bgo#710380).
  + Don't focus the no-focus-window for globally active windows
    (bgo#710296).
  + Misc. fixes and cleanups: bgo#709776.
  + Updated translations.
- Drop mutter-use-new-upower-api.patch: fixed upstream.
* Thu Feb 20 2014 zaitor@opensuse.org
- Update to version 3.10.4:
  + Fix CSD titlebars being placed off-screen (bgo#719772).
  + Expose MetaWindow:skip-taskbar property (bgo#723307).
  + Fix legacy tray icons showing up blank (bgo#721596).
  + Fix configuration of cloned monitors (bgo#710610).
  + Use correct output property for backlight control (bgo#723606).
  + Bugs fixed: bgo#720630, bgo#723468, bgo#724258, bgo#724364.
  + Updated translations.
* Fri Feb 14 2014 fcrozat@suse.com
- Update mutter-bell.patch: correctly get gsetting from the right
  schema [FATE#316042]
* Wed Feb  5 2014 idonmez@suse.com
- Add mutter-bell.patch to make audible bell work out of the box.
  Implements FATE#316042
* Sat Jan 18 2014 zaitor@opensuse.org
- Update to version 3.10.3:
  + xrandr: Use "hotplug_mode_update" property (bgo#711216).
  + Don't focus the no-focus-window for globally active windows
    (bgo#710296).
  + Fix window group paint volume (bgo#719669).
  + Fix checks for KeyPress/ButtonPress (bgo#720545).
  + Fix problems with focus tracking (bgo#720558).
  + Don't leave focus on windows that are being unmanaged
    (bgo#711618).
  + Reduce server grabs (bgo#721345, bgo#721709).
  + Updated translations.
* Wed Dec 11 2013 mgorse@suse.com
- Add mutter-use-new-upower-api.patch: Support UPower 0.99.
* Thu Nov 14 2013 dimstar@opensuse.org
- Update to version 3.10.2 (bnc#849913):
  + Fix resize operations using mouse-button-modifier (bgo#710251).
  + Updated translations.
* Wed Oct 16 2013 dimstar@opensuse.org
- Update to version 3.10.1.1:
  + Don't assert that at least one output is connected
    (bgo#709009).
- Changes from version 3.10.1:
  + Don't apply fullscreen workarounds to CSD windows (bgo#708718).
  + Fix hangs during DND operations (bgo#709340).
  + Use nearest-pixel interpolation when possible (bgo#708389).
  + Fix tile previews getting stuck on right click during drags
    (bgo#704759).
  + Misc bug fixes: bgo#708420.
  + Updated translations.
* Wed Sep 25 2013 dimstar@opensuse.org
- Update to version 3.10.0.1:
  + Fix bug when a window changed size twice in a single frame;
    this can happen with GTK+ client-side decorations (bgo#708367).
* Tue Sep 24 2013 dimstar@opensuse.org
- Update to version 3.10.0:
  + Updated translations.
* Tue Sep 17 2013 dimstar@opensuse.org
- Update to version 3.9.92:
  + Don't create a dummy texture for the texture pipeline template
    (bgo#707458).
  + Remove holes generated by disabling the laptop lid
    (bgo#707473).
  + Don't require plugins to pass event to Clutter (bgo#707482).
  + Add support for more cursor types (bgo#707919).
  + Immediately fire idle watches that are already expired
    (bgo#707302).
  + Bugs fixed: bgo#707474, bgo#707563, bgo#707649, bgo#708070.
* Tue Sep  3 2013 dimstar@opensuse.org
- Update to version 3.9.91:
  + Drop man pages for removed utilities (bgo#706579).
  + Add support for idle tracking (bgo#706005).
  + Skip CRTC reconfigurations that have no effect (bgo#706672).
  + Ignore skip-taskbar hints on parentless dialogs (bgo#673399).
  + Don't save pixbuf data in user data (bgo#706777).
  + Don't queue redraws for obscured regions (bgo#703332).
  + Turn blending off when drawing entirely opaque regions
    (bgo#706930).
  + Check event timestamps before reconfiguring (bgo#706735).
  + Misc bug fixes: bgo#706582, bgo#706598, bgo#706787,
    bgo#706729, bgo#706825, bgo#707081, bgo#707090, bgo#707250,
    bgo#707267.
  + Updated translations.
* Thu Aug 22 2013 dimstar@opensuse.org
- Update to version 3.9.90:
  + Add support for _GTK_FRAME_EXTENTS (bgo#705766).
  + Fix quick consecutive <super> presses breaking keyboard input
    (bgo#666101).
  + Work towards running as wayland compositor:
  - Add DBus API for display configuration (bgo#705670,
    bgo#706231, bgo#706233, bgo#706322, bgo#706382).
  - Add abstraction layer for cursor tracking (bgo#705911).
  - Add support for plugin modality under wayland (bgo#705917).
  + Disable GTK+ scaling (bgo#706388).
  + Disable blending while updating tower.
  + Misc bug fixes and cleanups: bgo#703332, bgo#704437,
    bgo#706207.
  + Updated translations.
- Add pkgconfig(upower-glib) and pkgconfig(gnome-desktop-3.0)
  BuildRequires: new dependencies.
- Drop now empty mutter-tools subpackage (empty, as the related
  utilities were removed upstream.
- Obsolete mutter-tools by the main package (not provided). This
  helps for clean updates.
* Tue Jul 30 2013 dimstar@opensuse.org
- Update to version 3.9.5:
  + Don't select for touch events on the stage (bgo#697192).
  + Don't queue redraws for obscured regions (bgo#703332).
  + Export timestamp of global keybinding events (bgo#704858).
  + Misc bug fixes and cleanups (bgo#703970).
* Wed Jul 10 2013 zaitor@opensuse.org
- Update to version 3.9.4:
  + Tweak window shadows (bgo#702141).
  + Ignore our own focus events for focus prediction (bgo#701017).
  + Add API to query if the stage is focused (bgo#700735).
  + Add API to query the monitor for a given position.
  + Don't force attached dialogs to be border-only (bgo#702764).
  + Allow slicing of backgrounds to avoid texture size limits
    (bgo#702283).
  + Miscellaneous bug fixes and cleanups: (bgo#701224, bgo#702564).
* Thu Jun 20 2013 dimstar@opensuse.org
- Update to version 3.9.3:
  + Ensure events are always reported to the grab window
    (bgo#701219).
  + Use new clutter_stage_set_paint_callback() function to prevent
    dropping frames with frame synced toolkits (bgo#698794).
* Tue May 28 2013 dimstar@opensuse.org
- Update to version 3.9.2:
  + Add meta_window_can_close() function (bgo#699269).
  + Add support for string-array preferences (bgo#700223).
  + Fix a potential race condition with _NET_WM_MOVERESIZE
    (bgo#699777).
  + Fix shade window action (bgo#693714).
  + Remove overlay_group (bgo#700735).
  + Improve tracking of the focus window (bgo#647706).
  + Add API to freeze/unfreeze the keyboard (bgo#697001).
  + Grab and emit a signal when XK_ISO_Next_Group is pressed
    (bgo#697002).
  + Other fixed bugs: bgo#699636, bgo#700735, bgo#697000.
  + Updated translations.
* Wed May  1 2013 dimstar@opensuse.org
- Update to version 3.9.1:
  + Fix miscellaneous memory leaks (bgo#698710).
  + Misc fixes and cleanups (bgo#698179, bgo#697758).
* Tue Apr 16 2013 dimstar@opensuse.org
- Update to version 3.8.1:
  + Fix crash when getting default font (bgo#696814).
  + Fix ungrabbing of keybindings (bgo#697003).
  + Misc fixes and cleanups: bgo#697758.
  + Updated translations.
* Wed Mar 27 2013 dimstar@opensuse.org
- Update to version 3.8.0:
  + Address major memory leak when changing backgrounds
    (bgo#696157).
  + Updated translations.
* Tue Mar 19 2013 zaitor@opensuse.org
- Update to version 3.7.92:
  + Build and improve reference docs (bgo#676856, bgo#695641,
    bgo#695935).
  + Add tracking of whether there are fullscreen windows
    (bgo#649748).
  + Bugs fixed: bgo#695269, bgo#695711, bgo#694046, bgo#695813,
    bgo#695881, bgo#676856, bgo#696053, bgo#682779, bgo#696089,
    bgo#696091, bgo#696087.
  + Updated translations.
* Tue Mar  5 2013 dimstar@opensuse.org
- Update to version 3.7.91:
  + Fix windows being treated as remote after hostname changes
    (bgo#688716).
  + Add meta_window_get_all_monitors() (bgo#646861).
  + Add grab API for externally defined accelerators (bgo#643111).
  + Make session registration an explicit step (bgo#694876).
  + Avoid unnecessary stage redraws (bgo#694988, bgo#695006).
  + Misc fixes: bgo#694801, bgo#694725, bgo#694641, bgo#694393,
    bgo#678917, bgo#695093, bgo#694837, bgo#695135, bgo#694771,
    bgo#694321.
  + Updated translations.
* Wed Feb 20 2013 dimstar@opensuse.org
- Update to version 3.7.90:
  + Support _NET_WM_OPAQUE_REGION (bgo#679901).
  + Add wrapper for XI2.3 pointer barriers (bgo#677215).
  + Update style of resize popups (bgo#692741).
  + Implement compositor <-> application frame synchronization
    (bgo#685463).
  + Handle animated backgrounds (bgo#682427).
  + Add a new window group for override-redirect windows
    (bgo#633620).
  + Pass on pointer events on guard window to Clutter (bgo#681540).
  + Show correct shortcut in window menus (bgo#694045).
  + Don't put minimized windows at the back of alt-tab
    (bgo#693991).
  + Misc bug fixes and cleanups: bgo#692679, bgo#693354,
    bgo#690581, bgo#693439, bgo#692718, bgo#693475, bgo#693482,
    bgo#693540, bgo#690580, bgo#680990, bgo#693833, bgo#693922,
    bgo#693854, bgo#694224.
  + Updated translations.
- Add pkgconfig(xi) BuildRequires: new dependency.
* Thu Feb 14 2013 dimstar@opensuse.org
- Update to version 3.7.5:
  + Don't allow multiline window titles (bgo#683056).
  + Make meta_window_located_on_workspace() public (bgo#691744).
  + Request XI2.3 (bgo#692877).
  + Add meta_window_set_icon_geometry() method (bgo#692997).
  + Require XFixes 5.0 (bgo#677215).
  + Change unredirection hints to match spec changes (bgo#693064).
  + Improve unredict heuristicts (bgo#683786).
  + Misc bug fixes and cleanups: bgo#691874, bgo#679901,
    bgo#692952, bgo#693042.
  + Updated translations.
- Drop mutter-correctly-create-new-pixmap.patch: fixed upstream.
* Thu Feb 14 2013 dimstar@opensuse.org
- Update to version 3.7.4:
  + Add support to bypass compositor hints (bgo#683020)
  + Make automaximization optional (bgo#680990)
  + Add method for checking if the application is responding
    (bgo#684340)
  + Expose the xinput opcode (bgo#690590)
  + Rebrand "minimize" as "hide" (bgo#682887)
  + Misc bug fixes and cleanups: bgo#690454, bgo#690573,
    bgo#690593, bgo#690956, bgo#691363, bgo#690609, bgo#690317,
    bgo#689263.
  + Updated translations.
- Drop BUILD_FROM_VCS logic, as it's not used anyway.
* Thu Feb 14 2013 zaitor@opensuse.org
- Update to version 3.7.3:
  + Fix maximized windows jumping to other monitors (bgo#556696)
  + Add 'switch-applications' keybinding (bgo#688913)
  + Add a convenience method to focus the default window
    (bgo#689652)
  + Increase typical icon size to 96 (bgo#689651)
  + Port to XInput2 (bgo#688779)
  + Give dynamic keybindings a keybinding action (bgo#682315)
  + Misc. fixes and cleanups (bgo#688777)
  + Updated translations.
- Drop mutter-stop-jumping-windows.patch: fixed upstream.
* Thu Feb 14 2013 dimstar@opensuse.org
- Update to version 3.7.2:
  + Fix spurious focus changes when showing desktop (bgo#686928)
  + MetaPluginManager: don't send events to Clutter twice
    (bgo#686406)
  + Add the ability to add shader hooks to MetaBackgroundActor
    (bgo#669798)
  + Only process keyboard mapping events for the core X keyboard
    (bgo#674859)
  + Import keybinding files from Metacity (bgo#687672)
  + Add compositor hook to process keybindings selectively
    (bgo#688202)
  + MetaBackgroundActor: add a setter for GLSL uniforms
    (bgo#682536)
  + Misc. fixes and cleanups: bgo#688182
  + Updated translations.
* Thu Feb 14 2013 dimstar@opensuse.org
- Update to version 3.7.1:
  + screen: Ignore num-workspaces when using dynamic workspaces
    (bgo#685439)
  + Updated translations.
* Thu Feb 14 2013 zaitor@opensuse.org
- Update to version 3.6.3:
  + Fix maximized windows jumping between monitors (bgo#556696).
  + Fix windows turning black when redirected again (bgo #693042).
  + Updated translations.
- Drop mutter-stop-jumping-windows.patch and
  mutter-correctly-create-new-pixmap.patch, fixed upstream.
* Sat Feb  9 2013 badshah400@gmail.com
- Add mutter-correctly-create-new-pixmap.patch to correctly create
  a new pixmap when redirecting a window again; patch taken from
  upstream git. Fixes bgo#693042.
* Tue Jan 22 2013 zaitor@opensuse.org
- Add mutter-stop-jumping-windows.patch, windows might in some
  cases jump from one monitor to an other, this patch fixes this.
  (bgo#556696).
* Tue Nov 13 2012 dimstar@opensuse.org
- Update to version 3.6.2:
  + Only process keyboard mapping events for the core X keyboard
    (bgo#674859)
  + Updated translations.
* Tue Oct 16 2012 dimstar@opensuse.org
- Update to version 3.6.1:
  + Fix crash when opening large popup menus (bgo#681676)
  + window: Don't move the desktop window after monitor hotplug
    (bgo#681159)
  + Expose MetaPlugin to introspection (bgo#671098)
  + Optionally delay focus changes in focus-follows-mouse mode
    (bgo#678169)
  + Resize the guard window when the X screen is resized
    (bgo#670396)
  + display: Only manage the default X screen (bgo#648156)
  + Misc cleanups (bgo#587255)
  + Updated translations.
* Tue Sep 25 2012 dimstar@opensuse.org
- Update to version 3.6.0:
  + Updated translations.
* Wed Sep 19 2012 dimstar@opensuse.org
- Update to version 3.5.92:
  + screen: Allow NULL out arguments in meta_screen_get_size
  + display: Add API to set wm_name / wm_keybindings (bgo#671010)
  + Improve the not responding dialog (bgo#684306)
  + Misc. bugfixes
  + Updated translations.
* Fri Sep  7 2012 vuntz@opensuse.org
- Split a mutter-data subpackage where we put data files (gsettings
  schema, keybindings, etc.) that are needed by libmutter0:
  + Without this, gnome-shell would not run if mutter is not
    installed (which shouldn't be necessary).
  + Move the use of %%glib2_gsettings_schema_* macros from the main
    subpackage to mutter-data.
  + Add a Requires for mutter-data to libmutter0.
- Split a typelib-1_0-Meta-3_0 metapackage:
  + The typelib is private, but we have no other choice than a
    subpackage:
  - it makes no sense to ship it as part of the mutter subpackage
    (since gnome-shell would then install it)
  - we can't ship it as part of libmutter0 because of the fixed
    dependencies it has.
  + Of course, this is abusing the package conventions for
    typelibs.
  + Add a typelib-1_0-Meta-3_0 Requires to devel subpackage.
- Move ownership of %%{_libdir}/mutter/plugins/ directory to
  libmutter0, since gnome-shell will need this directory too.
* Tue Sep  4 2012 dimstar@opensuse.org
- Update to version 3.5.91:
  + Fix subtracting unredirected windows from visible region
    (bgo#677116)
  + Minor improvements and bugfixes (bgo#682648, bgo#682993)
  + Updated translations.
* Sun Sep  2 2012 dimstar@opensuse.org
- Split out libmutter0 to follow SLPP (bnc#706930).
- Change mutter requires to libmutter0: it's all what's needed to
  develop against this library.
- Move /sbin/ldconfig calls from post/postun of the main package to
  libmutter0.
* Tue Aug 21 2012 dimstar@opensuse.org
- Update to version 3.5.90:
  + Fix logic for handling translations of the windows group
    (bgo#681221)
  + Handle painting inside a Clutter clone (bgo#681953)
  + Update overlay-key on settings changes (bgo#681906)
  + Add keybinding for overlay-key (bgo#665547)
  + Minor fixes and improvements
  + Updated translations.
- Drop gnome-doc-utils-devel BuildRequires: no longer needed.
* Tue Aug  7 2012 dimstar@opensuse.org
- Update to version 3.5.5:
  + Fix flickering around windows when using window group
    (bgo#681221)
  + Updated translations.
* Tue Jul 17 2012 dimstar@opensuse.org
- Update to version 3.5.4:
  + Make it possible to reimplement move-to-workspace keybindings
    from plugins (bgo#674104)
  + Add a preference to ignore hide-titlebar-when-maximized hint
    (bgo#678947)
  + window: Also use hide-titlebar-when-maximized when tiled
    (bgo#679290)
  + Center modal dialogs on their parent instead (bgo#674499)
  + Reduce amount of markup in translated messages (bgo#679660)
  + Fix focus problem after closing a window with
    focus-follows-mouse (bgo#675982)
  + Handle changes of the attach-modal-dialogs preference
    (bgo#679904)
  + Do not restore tiling on unmaximize (bgo#677565)
  + Bugs fixed: bgo#673824, bgo#679153)
  + Updated translations.
* Mon Jun 25 2012 dimstar@opensuse.org
- Update to version 3.5.3:
  + Simplify plugin system [bgo#676855]
  + meta-window-actor: Don't unredirect shaped windows [bgo#677657]
  + screen: Add new public meta_screen_get_current_monitor API
    [bgo#642591]
  + frames: Increase the size of resize corners [bgo#677669]
  + window: Make some window methods public [bgo#678126]
  + Fix crash when running mutter stand-alone [bgo#678238]
  + meta-window-actor: Fix potential crash in shaping code
    [bgo#677977]
  + Misc. fixes
  + Updated translations.
* Thu Jun  7 2012 dimstar@opensuse.org
- Update to version 3.5.2:
  + keybindings: Remove 'toggle-recording' binding [bgo#674376]
  + Switch to gtk-doc syntax [bgo#673752]
  + shaped-texture: never slice shape mask texture [bgo#674731]
  + Make Mutter stop relying on Cogl including a GL header
    [bgo#672711]
  + Make support for "XFree86" Xinerama mandatory [bgo#674727]
  + meta_window_move_frame(): fix crash when frame is NULL
    [bgo#675254]
  + Fix memory leaks [bgo#672640]
  + Code cleanups [bgo#671104, bgo#674876, bgo#676052]
  + Look for themes in XDG user data dir [bgo#675316]
  + Remove frame pixel caching [bgo#675111]
  + stack: Ignore keep-on-top property on maximized windows
    [bgo#673581]
  + Misc. fixes
  + Updated translations.
- Drop mutter-fix-crash-when-frame-is-NULL.patch: fixed upstream.
- Drop mutter-never-slice-shape-mask.patch: fixed upstream.
- Drop mutter-use-cogl-texrect-api.patch: fixed upstream.
* Thu May 31 2012 fcrozat@suse.com
- Add mutter-never-slice-shape-mask.patch,
  mutter-use-cogl-texrect-api.patch: Fix window texturing on
  hardware without ARB_texture_non_power_of_two (rh#813648,
  bgo#674731, bgo#672711).
* Sat May  5 2012 zaitor@opensuse.org
- Add mutter-fix-crash-when-frame-is-NULL.patch: fixes crashes in
  various extensions.
* Wed Apr 18 2012 vuntz@opensuse.org
- Update to version 3.4.1:
  + API change: the meta_display_add_keybinding() function added in
    3.4 wasn't usable from a GNOME Shell extension, so has been
    changed to take a GSettings object rather than the name of a
    schema [bgo#673014]
  + Don't try to auto-maximize not-maximizable windows; this fixes
    the problem with the Nautilus desktop window being
    mis-positioned when enabled [bgo#673566]
  + Fix a crash in the default plugin (not used in GNOME)
    [bgo#673809]
  + Make the <Super> key work when set as the mouse button modifier
    [bgo#662476]
  + Updated translations.
* Mon Mar 26 2012 vuntz@opensuse.org
- Update to version 3.4.0:
  + Fix crash when a full-screen window is opened [bgo#672797]
  + Fix memory leaks [bgo#672640]
  + Updated translations.
* Tue Mar 20 2012 dimstar@opensuse.org
- Update to version 3.3.92:
  + Automaximize large windows on map (bgo#671677).
  + When unmaximizing windows, make sure the unminimized size
    is signficantly less than the maximized size (bgo#671677).
  + Don't offer maximize option for windows larger than the screen
    (bgo#643606).
  + Always focus the window immediately underneath without
    restacking when closing a window (bgo#620744).
  + Avoid drawing shadows when two windows are tiled together
    (bgo#643075).
  + Remove tooltips for window decorations (bgo#645101)
  + Add org.gnome.mutter.dynamic-workspaces GSetting - when this is
    set to true, workspace counts are never saved to GSettings,
    avoiding pointless disk traffic for GNOME dynamic workspaces
    (bgo#671568).
  + Add ::grab-op-begin, ::grab-op-end signals to MetaDisplay
    (bgo#670658).
  + Add meta_display_get_ignored_modifier_mask() (bgo#665215).
  + Remove pointless wrapper methods on MetaPlugin (bgo#671103).
  + Fix frame drawing with 3.3.x GTK+ releases (bgo#671796).
  + Build fixes.
  + Bugs fixed: bgo#661256, bgo#667437, bgo#671087, bgo#671601,
    bgo#672374.
  + Updated translations.
* Thu Feb 23 2012 vuntz@opensuse.org
- Update to version 3.3.90:
  + Update for Cogl API changes
  + Bug fixes (including bgo#659643)
  + Build fixes
  + Updated translations.
- Change clutter-devel and gtk3-devel BuildRequires to
  pkgconfig(clutter-1.0) and pkgconfig(gtk+-3.0).
- Add explicit pkgconfig() BuildRequires: cairo, cogl-1.0, gio-2.0,
  pango.
* Mon Feb 20 2012 vuntz@opensuse.org
- Add explicit libSM-devel, libX11-devel, libXext-devel,
  libXinerama-devel, libXrandr-devel, pkgconfig(xcomposite),
  pkgconfig(xcursor), pkgconfig(xdamage), pkgconfig(xfixes),
  pkgconfig(xrender) BuildRequires: we need all of those, and some
  are not implicitly brought in after the big xorg-x11 packaging
  change.
* Wed Feb  8 2012 vuntz@opensuse.org
- Update to version 3.3.5:
  + MetaShapedTexture no longer is a ClutterTexture subclass
    [bgo#660941]
  + Add meta_shaped_texture_get_image() [bgo#660941]
  + Cleanups [bgo#657639]
  + Updated translations.
- Remove xz BuildRequires now that it comes for free in the build
  system.
- Split non-essential tools to a mutter-tools subpackage.
- Stop checking for non-supported versions of openSUSE (<= 11.1).
- Stop passing --disable-schemas-install to configure: there is no
  gconf schema anymore.
- Stop changing libexecdir in configure: there is no need for that.
* Fri Jan 20 2012 vuntz@opensuse.org
- Update to version 3.3.4:
  + Adapt to changes in GtkStateFlags
  + Redo properties for applications menu corresponding to GTK+
    changes - they are now _GTK_* not DBUS_*.
  + Fix crash on gnome-shell restart when a modal dialog is open
    [bgo#668299]
  + Code cleanup [bgo#666039]
  + Updated translations.
- Drop mutter-fix-build-latest-gtk3.patch: fixed upstream.
* Wed Jan 18 2012 vuntz@opensuse.org
- Add mutter-fix-build-latest-gtk3.patch: fix build caused by an
  API change in GTK+ 3.3.8.
* Thu Jan  5 2012 vuntz@opensuse.org
- Update to version 3.3.3:
  + Add keybindings for tiling to left or right [bgo#648700]
  + Support GTK+'s hide-titlebar-when-maximized hint [bgo#665617]
  + Load _DBUS_APPLICATION_ID, _DBUS_UNIQUE_NAME, _DBUS_OBJECT_PATH
    property [bgo#664851]
  + Handle changes to workspaces-only-on-primary GSetting
    [bgo#664853]
  + Don't use the Clutter default stage [bgo#664028]
  + Fix compilation with --disable-introspection [bgo#661871]
  + Fix problem where stage could end up mis-sized on startup with
    multiple monitors
  + Misc bug fixes [bgo#666015]
  + Updated translations.
- Add xz BuildRequires because we can't build a package for a
  xz-compressed tarball without explicitly specifying that... See
  bnc#697467 for more details.
* Mon Dec 12 2011 vuntz@opensuse.org
- Drop mutter-clutter-1.10.patch: this actually breaks mutter as we
  need a clutter patch too, which is not ready yet.
- Pass --enable-compile-warnings=maximum to configure: the default
  is error, and we don't want to have -Werror in our CFLAGS.
* Tue Nov 22 2011 dimstar@opensuse.org
- Update to version 3.3.2:
  + Move from GConf to GSettings for preferences [bgo#635378]
  + meta_display_add_keybinding()/meta_display_remove_keybinding()
    added to allow creating new keybindings at runtime [bgo#663428]
  + Add suport for new _NET_WM_STATE_FOCUSED atom in _NET_WM_STATE
    to allow applications to draw unfocused windows differently
    [bgo#661427]
  + Add meta_window_move_resize_frame() to allow specifying the
    size and position of a window via the outside dimensions of the
    window frame.
  + Don't activate window tiling when moving in snap mode
    [bgo#662270]
  + Remove the ability to resize a window from the inner edge of
    the titlebar [bgo#660129]
  + Fix for deprecations in GTK+ [bgo#662574, bgo#662895]
  + Bugs fixed: bgo#662895, bgo#642652, bgo#660941, bgo#662225
  + Updated translations.
- Add mutter-clutter-1.10.patch: Fix build with clutter 1.10.
- Add pkgconfig(gsettings-desktop-schemas) BuildRequires: new
  dependency.
- Drop gconf-devel BuildRequires: migration to GSettings completed.
- Replace gconf schema packaging machinery with
  %%glib2_gsettings_schema_* macros.
* Tue Oct 18 2011 dimstar@opensuse.org
- Update to version 3.2.1:
  + Allow keyboard window switching (alt-Tab) during drag-and-drop
    [bgo#660457]
  + Don't add invisible resize borders to fullscreen windows
    [bgo#659854]
  + Fix crash when toplevel windows were set to unexpected window
    types [bgo#599988]
  + Correct problems with windows moving when restarting or
    switching window managers [bgo#660848]
  + Fix interaction of tiled windows with multiple monitors
    [bgo#657519]
  + Make meta_display_unmanage_screen() public [bgo#660848]
  + Fix problem with turning off window decorations on the fly
    [bgo#660773]
  + Fix spurious assertion failures with themes such as Nodoka
    [bgo#661286]
  + Misc bug fixes [bgo#660464, bgo#660854, bgo#662053]
  + Updated translations.
* Mon Sep 26 2011 vuntz@opensuse.org
- Update to version 3.2.0:
  + Fix _NET_WM_FRAME_EXTENTS not to include invisible borders
    [bgo#659848]
  + Fix application-specified window placement (-geometry) for
    invisible borders [bgo#659848]
  + Updated translations.
* Wed Sep 21 2011 vuntz@opensuse.org
- Update to version 3.1.92:
  + Fix bug with unredirecting full-screen windows on
    multi-monitor, notably affected gnome-screensaver [bgo#657869]
  + Disable top resizing of attached dialogs [bgo#657795]
  + Code cleanup
  + Misc bug fixes [bgo#658069, bgo#659266, bgo#659523, bgo#659477]
  + Updated translations.
* Thu Sep 15 2011 vuntz@opensuse.org
- Update to version 3.1.91.1:
  + Fix problem where certain application updates would get lost
    [bgo#657071]
  + Fix a problem where after resuming from the screensaver, things
    got slow [bgo#658228]
  + When a monitor is plugged or unplugged, keep existing windows
    on their current monitor [bgo#645408]
  + Remove 'Mutter' title from alerts such as
    "The window '%%s' is not responding"
  + Remove pointless warning:
    Received a _NET_WM_MOVERESIZE message for %%s; these
    messages lack timestamps and therefore suck.
  + Misc bug fixes
  + Build fixes
  + Updated translations.
* Thu Sep  1 2011 vuntz@opensuse.org
- Update to version 3.1.90.1:
  + Fix crash when no windows are open [bgo#657692]
  + Fix annotations for new strictness in gobject-introspection
  + Fix some errors with rounded frame drawing [bgo#657661]
- Changes from version 3.1.90:
  + Extend the draggable portion of window borders outside the
    visible frame for easy resizing with thin borders. (New
    draggable_border_width GConf key controls the total width of
    visible and invisible borders.) [bgo#644930]
  + Draw rounded window corners with antialising [bgo#628195]
  + Unredirect override-redirect fullscreen windows, such as
    full-screen 3D games to avoid any performance impact
    [bgo#597014]
  + Add :resizable and :above properties to MetaWindow.
    [bgo#653858]
  + Add MUTTER_DISABLE_FALLBACK_COLOR environment variable to allow
    visualizing places where a color is missing for gtk:custom()
    colors [bgo#656112]
  + Don't attach modal dialogs to special windows like the desktop;
    add meta_window_is_attached_dialog() [bgo#646761]
  + Make MetaBackgroundActor public, allow creating multiple
    instances (sharing a common texture), and add a :dim-factor
    property [bgo#656433]
  + Fix attached dialogs to not be resizable from the top and to be
    position correctly [bgo#656619]
  + Misc bug fixes [bgo#656335, bgo#657583]
  + Updated translations.
* Thu Jul 28 2011 vuntz@opensuse.org
- Update to version 3.1.4:
  + Use better, much more subtle shadow definitions [bgo#649374]
  + Add the ability to use named GTK+ colors in theme files as
    gtk:custom(name,fallback) [bgo#648709]
  + Port from GdkColor to GdkRGBA and from GtkStyle to
    GtkStyleContext [bgo#650586]
  + Try to fix window bindings using the Super key [bgo#624869]
  + Update to using more modern Cogl and Clutter APIs [bgo#654551,
    bgo#654729, bgo#654730, bgo#655064]
  + Fix for srcdir != builddir builds [bgo#624910]
  + Make handling of focus appearance for attached dialogs more
    robust [bgo#647712]
  + Misc bug fixes: bgo#642957, bgo#649374, bgo#650661, bgo#654489,
    bgo#654539.
* Sat Jul  2 2011 vuntz@opensuse.org
- Update to version 3.1.3.1:
  + Back API version down to "3.0": the change to Meta-3.1.gir was
    unintentional.
  + Updated translations.
* Fri Jul  1 2011 dimstar@opensuse.org
- Update to version 3.1.3:
  + bgo#645355: Support dark window theme variants for windows with
    a dark widget theme; this is selected by the _GTK_THEME_VARIANT
    property
  + bgo#635268: Don't draw a shadow under windows with an alpha-
    channel - this fixes transparency for GNOME Terminal
  + bgo#649315: Add a MetaWindow:wm-class property for notification
  + Add a MetaWindow:minimized property for notification
  + bgo#627880: Fix handling of unusual window shapes that Wine was
    setting causing some applications to draw wrong
  + bgo#653121: Improve replacing another compositor and being
    replaced: release compositor selection in the right order and
    wait for compositors that get it wrong.
  + bgo#652369: Remove behavior where left clicking on a window
    border with the titlebar offscreen gave the window menu
  + bgo#649202: Don't set the global default textdomain, since
    Mutter is a library as well as an application
  + Exit with the right (success or failure) exit status
  + Code cleanup
  + Other bugs fixed: bgo#649114, bgo#652507
  + Updated translations.
- Process %%{_datadir}/gnome/wm-properties/mutter-wm.desktop with
  suse_update_desktop_file to fix a rpmlint warning.
* Thu May 26 2011 dimstar@opensuse.org
- Update to version 3.0.2.1:
  + bgo#648828: When saving the session, use the "program name"
    rather than harcoding mutter, fixing session saving for
    gnome-shell.
- Changes from version 3.0.2:
  + bgo#647777: Fix a crash when running without XKB support
  + bgo#649500, bgo#649504: Fix smallish memory leaks
  + bgo#649299: Ignore mirrored monitors when listing monitors,
    fixing drag-and-drop problems in GNOME Shell
  + Don't allow side-by-side tiling of non-maximizable windows
    like dialogs and utility windows
  + bgo#648613: Fix interaction of _NET_WM_WINDOW_OPACITY with
    window effects, making it work again with GNOME Shell
  + Updated translations.
* Wed Apr 27 2011 fcrozat@novell.com
- Update to version 3.0.1:
  + bgo#647662: if WM_CLIENT_MACHINE isn't set, don't assume a
    window is remote; fixes behavior of Fox toolkit applications
    under GNOME Shell.
  + bgo#647613: fix cases where windows could get stuck drawing as
    focused after an attached modal dialog was closed.
  + Fix a bug where a window that is too big to be tiled
    side-by-side would behave strangely when using the gesture of
    dragging to the top to maximize.
  + Updated translations.
* Tue Apr  5 2011 fcrozat@novell.com
- Update to version 3.0.0:
  + Avoid crashing when you have a single window and try to move it
    between workspaces. bgo#642957.
  + Updated translations.
* Tue Mar 29 2011 fcrozat@novell.com
- Update to version 2.91.93:
  + bgo#645408: Fix bug where, when a monitor was hot-plugged, all
    workspaces would collapse to a single workspace. (There are
    still issues when a secondary monitor is hot-plugged to the
    left of the primary monitor).
  + bgo#645843: Fix a crash for the cycle_group action
  + bgo#636904: Fix misdrawing of window shadows on some focus
    changes.
  + bgo#645590: Export meta_get_replace_current_wm() to allow
    fixing a GNOME Shell bug with --replace.
  + Updated translations.
- Changes from version 2.91.92:
  + Add a workspaces_only_on_primary preferences. When set, this
    makes workspaces switching only apply to windows on the primary
    monitor, while windows on other monitors are unaffected.
  + Export API for monitor handling:
    MetaScreen::monitors-changed signal
    meta_screen_get_primary_monitor()
    meta_window_is_on_primary_monitor()
    meta_window_get_monitor()
    MetaWindow::window-entered-monitor,
    MetaWindow::window-left-monitor.
    meta_window_move_to_monitor()
  + Behavior improvements for attached modal dialogs:
  - Allow dragging dragging on the titlebar to move the  parent
  - Allow resizing
  - Constrain to be on the current monitor
  + Don't turn on XSMP autorestart
  + Combine libmutter-wm and libmutter-private into a single
    libmutter.
  + Export methods to move and resize windows
    meta_window_move(), meta_window_resize(),
    meta_window_move_frame().
  + Add a MUTTER_WM_CLASS_FILTER environment variable to allow
    existing windows to be ignored when performance testing.
  + Add a new compositor-based flash for visual bell
  + Fix bug where application specified values for properties like
    "skip taskbar" were sometimes ignored.
  + Bug fixes.
  + Build fixes
- Changes from version 2.91.91:
  + Build a libmutter-wm that contains all of the logic and that
    can be linked to to create custom executables. The mutter
    executable becomes a small stub linked to this library.
  + Move installed headers files into a meta/ subdirectory instead
    of polluting the toplevel namespace.
  + Remove various unused complications:
  - Ability to set the set of plugins via GConf
  - Plugin 'params'
  - meta_restart() and "mutter-message restart"
  + Don't exit when we are requested to exit via XSMP, assume we'll
    be killed along with the X server; this avoids visual artifacts
    from unmanaging windows when logging out.
  + Build fixes
- Changes from version 2.91.90:
  + Change <Alt>Above_Tab from being a cycle_group binding to
    a switch_group binding
  + Make plugin-loading failure fatal
  + Add 'position-changed' signal to MetaWindowActor
  + When 'live_hidden_previews' is enabled, position hidden
    windows to allow the creation of workspace previews
  + Fix bug with opacity of MetaBackgroundActor
- Fix BuildRequires to use pkgconfig(libcanberra-gtk3)
* Mon Feb 14 2011 sbrabec@suse.cz
- Added support for translation-update-upstream.
* Sun Feb 13 2011 vuntz@opensuse.org
- Call relevant macros in %%post/%%postun:
  + %%desktop_database_post/postun because the package ships at
    least one desktop file.
- Pass %%{?no_lang_C} to %%find_lang so that english documentation
  can be packaged with the program, and not in the lang subpackage.
- Change Requires of lang subpackage to Recommends, since the
  english documentation is not there anymore.
* Fri Feb 11 2011 fcrozat@novell.com
- Update to version 2.91.6:
  + Add meta_screen_override_window_layout() to let a plugin set
    the workspace layout
  + Add a 'size-changed' signal to MetaWindowActor
  + Add meta_window_actor_is_destroyed()
  + Fix problems with window tile previews when cancelling a move
  + Port theme elements that use GTK+ drawing to use
    GtkStyleContext instead of the deprecated GtkStyle.
  + Fix compiler warnings that were causing compilation failures
  + Misc bug fixes
  + Updated translations.
- Add support for source service checkout, with %%BUILD_FROM_VCS:
  + Add gnome-common BuildRequires.
  + Add call to ./autogen.sh.
- Change libcanberra-devel BuildRequires to
  pkgconfig(libcanberra-gtk).
- Remove --with-gtk=3.0 configure option: it's always built against
  GTK+ 3 now.
* Fri Jan 14 2011 vuntz@opensuse.org
- Update to version 2.91.5:
  + Add a Above_Tab key symbol that can be used in key bindings to
    mean the key above the Tab key. This is now the default binding
    for cycle_group in both Mutter and Metacity.
  + Add new frame states for tiled-on-the-left and
    tiled-on-the-right
  + Add new background drawing functions that can be defined in a
    theme for single buttons.
  + Draw the right button backgrounds for all custom button layouts
  + Remove vestigal --composite/--no-composite command line options
  + Fix building on GLES
  + Code cleanups
  + Bugs fixed: bgo#613124, bgo#626875, bgo#629282, bgo#635569,
    bgo#635683, bgo#635686, bgo#637330.
  + Updated translations.
* Fri Jan  7 2011 vuntz@opensuse.org
- Update to version 2.91.4:
  + Update for GTK+ 3 changes.
  + Support maximizing a window by dragging to the top of the
    screen in the same way you can tile by dragging to the edge of
    the screen.
  + Misc bug fixes.
  + Bugs fixed: bgo#630548, bgo#636083, bgo#636301, bgo#636302,
    bgo#636491, bgo#637802.
  + Updated translations.
- Drop mutter-gdk_functions.patch, mutter-gtk_states.patch,
  mutter-port-testgradients-to-gtk3.patch: they're all fixed
  upstream.
- Move %%{_libdir}/mutter/Meta-2.91.gir to devel subpackage.
* Tue Dec 14 2010 dimstar@opensuse.org
- Add patches from upstream git to fix build with latest gtk3L:
  + mutter-gdk_functions.patch: commit 8994e6
  + mutter-port-testgradients-to-gtk3.patch: commit d74659
  + mutter-gtk_states.patch: commit 544c8.
* Tue Nov 30 2010 dimstar@opensuse.org
- Update to version 2.91.3:
  + Better shadows:
  - Shadows can be different for different window types and focus
    states
  - Shadows are larger by default, especially for the currently
    active eindow
  - Shadows for attached modal dialogs and menus are drawn not to
    overlap the attachment point.
  - Shadows follow the shape of shaped windows
  + Optimization:
  - Avoid repainting in situations when windows are potentially
    restacked but aren't actually restacked.
  - Pay attention to partial stage repaints in obscured window
    calculations
  - Better optimization of painting obscured shadows; turn off
    shadows for maximized windows.
  - Move background repainting into Mutter; doing it here rather
    than in plugins allows not painting obscured parts of the
    background.
  + A new frame type 'attached' is added for attached modal dialogs
    and can be referenced in theme files with a theme version 3.2.
  + Fix updating key bindings when the keyboard layout changes
  + Bug fixes
  + Build fixes
  + Updated translations.
* Tue Nov  9 2010 vuntz@opensuse.org
- Update to version 2.91.2:
  + Remove support for GTK+ 2
  + Adapt to deprecation of size_request deprecation in GTK+
  + Include change from Metacity to fix confusion of mouse tracking
    when double-clicking on title bar
  + Fix bug with the the window menu getting stuck when you alt-Tab
  + Bugs fixed: bgo#633133, bgo#633352, bgo#633398, bgo#633401
  + Updated translations.
* Thu Oct 28 2010 vuntz@opensuse.org
- Update to version 2.91.1:
  + Default build is now GTK+ 3 build
  + Mutter namespace prefix is removed, in favor of consistent
    meta_ namespace prefixing. Naming changes:
    MutterWindow              => MetaWindowActor
    mutter_get_windows        => meta_get_window_actors
    mutter_plugin_get_windows => meta_plugin_get_window_actors
  + Add missing values in MetaKeyBindingAction; this fixes a
    problem where key binding lookup wasn't working properly for
    some key bindings.
  + Remove keysym parameter to
    meta_display_get_keybinding_action(); the function expected the
    default keysym for the keycode to always be passed
  + Clean up installed header files; in particular, theme-parser.h
    is merged into a new public-only theme.h and private internals
    are moved to theme-private.h.
  + Fix problems with antialiased rendering of themes
  + Fix problem with parsing color constants in themes
  + Build fixes
  + Miscellaneous bug fixes
  + Fixed bugs: bgo#628401, bgo#628520, bgo#631487, bgo#632116,
    bgo#632149, bgo#632155, bgo#632474, bgo#632494.
  + Updated translations.
* Thu Oct 14 2010 vuntz@opensuse.org
- Remove explicit Requires for clutter-devel and gtk2-devel in
  devel package: they will automatically be added the pkgconfig()
  way.
* Tue Oct  5 2010 vuntz@opensuse.org
- Update to version 2.91.0:
  + Enable side-by-side tiling via a gesture of dragging to the
    left or right edge of the screen. (enabled with an
    off-by-default GConf key)
  + Allow breaking out of maximization/tiling using a
    alt-middle-button window resize
  + Add the ability to have modal dialogs attached to their parent
    window (enabled with an off-by-default GConf key)
  + Draw with Cairo rather than GDK
  + Add compatibility for changes in GTK+ 3
  - libmutter-private is now only installed for GTK+ 3 builds
  - Theme parts of libmutter-private API are changed to take
    cairo_t rather than GdkDrawable
  + Update introspection build and annotations for new behavior of
    g-ir-scanner
  + Fix bug that caused window menu options not to work
  + Fix misbehavior of Wine windows
  + Fix crashes from missing error traps
  + Build fixes
  + Misc bug fixes
  + Cleanups
  + Updated translations.
- Drop mutter-gdk-cairo.patch, mutter-no-gdk_display.patch,
  mutter-gdk-keys.patch: fixed upstream.
* Sat Sep 18 2010 vuntz@opensuse.org
- Add mutter-no-gdk_display.patch: stop using gdk_display that got
  removed in recent GTK+ 3 versions.
- Add mutter-gdk-keys.patch: update the code after some API changes
  in GDK 3.
* Thu Sep  2 2010 dimstar@opensuse.org
- Add mutter-gdk-cairo.patch: replace GDK Drawing API with cairo.
  This fixes building with GTK3 2.90.6.
* Wed Sep  1 2010 vuntz@opensuse.org
- Drop gir-repository BuildRequires: the introspection files that
  were needed from there are now directly with the appropriate
  libraries.
* Fri Jul 16 2010 dimstar@opensuse.org
- Update to 2.31.5:
  + Support building with GTK+ 3.0
  + Remove deprecated usages for compatibility with GTK+ 3.0
  + Export a boxed type for MetaRectangle
  + Allow disabling -Werror with --enable-compile-warnings=yes
  + Build fixes
- Build against GTK+ 3: use gtk3-devel BuildRequires instead of
  gtk2-devel and pass --with-gtk=3.0 to configure.
* Mon Jul  5 2010 dimstar@opensuse.org
- Update to version 2.31.4:
  + Clean up MutterPlugin effect interface
  + Track damage as the bounding box, a significant optimizations
    for rapidly drawing clients
  + Add meta_window_is_remote()
  + Add meta_add_debug_topic() for turning on logging of specific
    topics
  + Fix bug with window unmaximization
  + Bugs fixed:
  - bgo#611838: expose sub-stage redraws by streaming raw updates
    to ClutterX11TexturePixmap
  - bgo#620585: Add meta_window_is_remote
  - bgo#620860: function ‘meta_display_open’
  - bgo#621082: MutterPluginManager should call
    plugin->switch_workspace, when screen doesn't have any
    window. Or function should be renamed.
  - bgo#621413: Maximize/Unmaximize not behaving properly for
    some non-gnome based programs
  + Updated translations.
* Fri May 28 2010 dimstar@opensuse.org
- Update to version 2.31.2:
  + Theme enhancements
  - Add a flexible version mechanism for themes -
    metacity-theme-3.xml is now supported, and can include
    version="> 3.2" type attributes on the root element or
    any subelement.
  - Add frame_x_center/frame_y_center variables
  - Allow a theme to turn on title ellipsization
  + Performance enhancements:
  - Stream raw damage updates to ClutterX11TexturePixmap
    to enable partial stage updates when windos change
  - Don't trap XErrors in meta_compositor_process_event
  + Add meta_prefs_override_preference_location(); this allows
    a plugin like GNOME Shell to redirect preferences to a
    plugin-specific location.
  + Support a _MUTTER_HINTS window property; this is a string
    property holding key-value pairs with plugin-specific
    interpretation
  + Build with GSEAL_ENABLE
  + Add meta_display_get_leader_window()
  + Add meta_display_sort_windows_by_stacking
  + Export
    meta_display_get_last_user_time()
    meta_display_xserver_time_is_before()
    meta_window_foreach_ancestor(),
    meta_window_foreach_transient()
    meta_window_lower()
    meta_window_raise()
    meta_window_set_demands_attention()
    meta_window_unset_demands_attention()
  + Bug fixes
  + Build fixes
- Drop mutter-gcc45.patch, fixed upstream.
* Fri Mar 19 2010 dimstar@opensuse.org
- Update to version 2.29.1:
  + Support and require Clutter 1.2
  + Add meta_display_get_keybinding_action()
  + Add meta_window_get_wm_class_instance()
  + Remove workaround for bug fixed in intel driver Q2/2009 release
  + Build fixes
  + Updated translations.
- Drop upstreamed patch mutter-cogl_texture-deprecated.patch.
* Thu Feb 25 2010 dominique.leuenberger@tmf-group.com
- Refresh mutter-cogl_texture-deprecated.patch to also take care
  of cogl_material_[un]ref, which is deprecated with clutter
  1.1.14.
* Fri Feb 19 2010 dimstar@opensuse.org
- Update to version 2.29.0:
  + Improve appearance of scaled down windows using mipmap
    emulation
  + Added signals: MetaDisplay::window-created,
    MetaDisplay::window-marked-urgent,
    MetaDisplay::window-demands-attention, MetaWindow::unmanaged
  + Added properties: MetaWindow:demands-attention,
    MetaWindow:urgent, MetaWindow:maximized-horizontally,
    MetaWindow:maximized-vertically
  + Fix nasty crash when workspace "struts" changed during a window
    move
  + Bug fixes
  + Build fixes
  + Merge Metacity changes since 2.26. Includes themable sound
    support via libcanberra
- BuildRequire libcanberra-devel for new themable sounds.
- Add mutter-cogl_texture-deprecated.patch to fix build against
  clutter 1.1.12. Reported upstream as bgo#610454.
* Wed Feb  3 2010 vuntz@opensuse.org
- Add mutter-fix-build.patch and mutter-gl-no-cgl.patch to fix the
  build with recent introspection data and with recent clutter.
* Wed Dec  2 2009 vuntz@opensuse.org
- Update the way we remove the ha, la, ig locales for old versions
  of openSUSE.
* Thu Oct  8 2009 vuntz@opensuse.org
- Update to version 2.28.0:
  + Add meta_window_get_stable_sequence
  + mutter_begin_modal_for_plugin(): Check result of
    XGrabKeyboard()
  + mutter_plugin_get_windows returns *Mutter*Window, not
    MetaWindow
  + Remove MetaAltTabHandler
  + Use "later functions" to fix priority problems with Clutter
    redraw
  + Create the dummy timeline for repaint laters with an "infinite"
    duration
  + Added meta_window_get_transient_for_as_xid()
  + Added workareas-changed signal
  + Work around race condition focusing a window on a different
    workspace
  + Updated translations.
* Wed Sep 16 2009 lmedinas@opensuse.org
- Update to version 2.27.5:
  + Fix bug in GConf schemas where the overview activation key was
    specified as '<Super_L>' not 'Super_L'.
  + Updated translations.
* Wed Sep  9 2009 vuntz@opensuse.org
- Update to version 2.27.4:
  + See http://git.gnome.org/cgit/mutter/log/?id=2.27.4
  + Add new API for plugins.
  + Refer to monitors as "monitors" rather than "xineramas"
  + Fix broken META_IS_SCREEN macro
  + Fix owner and applyto for /apps/mutter/general/overlay_key
    schema
  + Make user-time a GObject property
  + Use meta_window_set_user_time for setting user time
    consistently
  + Export a _GNOME_WM_KEYBINDINGS property
  + Build fixes.
  + Updated translations.
* Sat Aug 29 2009 vuntz@novell.com
- Update to version 2.27.3:
  + See http://git.gnome.org/cgit/mutter/log/?id=2.27.3
  + Do not run effects during WM startup
  + Remove meta_errors_register_foreign_display()
  + Check the opacity of the right actor
  + Always notify on title property change
  + Avoid accessing freed memory when being replaced
  + Fix alt-tab with urgent windows
  + Enforce a policy of single-handling of key events
  + Add a modal mode for plugins
  + Fix custom-alt-tabs for single-handling of key events
  + Check for NULL in meta_screen_tab_popup_destroy() instead of
    asserting
  + Unminimize windows passed to
    meta_workspace_activate_with_focus()
  + Add new API for plugins.
  + Various minor fixes.
  + Updated translations.
* Thu Aug 13 2009 vuntz@novell.com
- Update to version 2.27.2:
  + Fix confusion about MetaPreview in introspection build
  + Queue redraws on MutterWindow's MutterShapedTexture
  + Pass event to clutter when the plugin doesn't have
    xevent_filter
  + Build using Clutter 1.0
  + Don't explicitly set the size of the MutterWindow texture
  + Pass through all scroll events to compositor
  + Tolerate all standard _NET_WM_WINDOW_TYPE types for managed
    windows
  + Set up correct initial values for override redirect windows
  + Add focus-window property to MetaDisplay
  + Accessors for pid and name of client machine associated with
    MetaWindow
  + Added MetaWindow::window-type property
  + Added public prototype for
    meta_window_is_ancestor_of_transient()
  + Avoid overflow when window maximum size hint is set to INT_MAX
  + Fix check for zero-sized textures in MutterShaped texture
  + Remove deprecated glib/gtk symbols
  + Handle FocusIn events for override redirect windows correctly
  + Elimitate use of arithmetic expansion for portability
  + Don't allow override-redirect windows to be META_WINDOW_NORMAL
  + Free MutterWindow description string in finalize() not
    dispose()
  + Take extra reference on the texture inside MutterWindow
  + Use correct timestamp for focus stealing prevention
  + Export meta_screen_get_startup_sequences, add change signal
  + Fix use of uninitialized memory in edge-resistance.c
  + Updated translations.
- Drop mutter-build-fix.patch: fixed upstream.
- Drop mutter-clutter-1.0.patch: fixed upstream.
- Remove gnome-common BuildRequires and gnome-autogen.sh call.
* Mon Aug  3 2009 vuntz@novell.com
- Add mutter-clutter-1.0.patch to fix build with clutter 1.0.
* Tue Jul 21 2009 vuntz@novell.com
- Update to version 2.27.1, first official tarball.
- Add mutter-build-fix.patch to fix build.
* Thu May 14 2009 vuntz@novell.com
- Update to git version as of May 14th.
* Mon May  4 2009 vuntz@novell.com
- Add tarball created from git, and mutter-rename.patch.bz2 to make
  mutter parallel-installable with metacity.
* Fri May  1 2009 vuntz@novell.com
- Initial package, based on the metacity package.
